@@ -1,7 +1,10 @@
 package Evo::Comp;
-use Evo '-Export *', ':Hash';
+use Evo '-Export *';
+use Evo::Comp::Hash ();
 export_proxy('Evo::Comp::Hash', '*');
 
+sub import($me, @args) { export_install_in(scalar caller, $me, @args ? @args : '*') }
+
 1;
 
 __END__
@@ -16,7 +19,7 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 DESCRIPTION
 
