@@ -1,13 +1,18 @@
 package Evo::Io;
-use Evo '-Export *; -Lib::Net *; Symbol gensym; :Handle; :Socket; Carp croak';
+use Evo '-Export *; -Lib::Net *; Symbol gensym; :Handle; :Socket; Carp croak; File::Temp tempfile';
 use Socket qw( SOCK_STREAM AF_INET AF_INET6 IPPROTO_TCP SOMAXCONN);
 
 our @CARP_NOT = qw(Evo::Net::Server::Role);
 
-sub io_open($mode, $expr, @list) : Export {
+use Fcntl qw(O_NONBLOCK O_RDONLY O_WRONLY O_RDWR);
+
+my %MAP = (r => O_RDONLY, w => O_WRONLY, rw => O_RDWR);
+
+sub io_open($mode, $filename, @extra) : Export {
   my $fh = Evo::Io::Handle::init(gensym());
-  open($fh, $mode, $expr, @list) || die "open: $!";    ## no critic
-  $fh->io_non_blocking(1);
+  $mode = $MAP{lc $mode} if exists $MAP{lc $mode};
+  sysopen($fh, $filename, $mode | O_NONBLOCK, @extra) || die "open: $!";    ## no critic
+  $fh;
 }
 
 sub io_open_anon : Export {
@@ -57,16 +62,19 @@ Evo::Io
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head2 io_open
 
-  my $io = io_open('>', $filename);
+  # 'r', 'w', 'rw', or constants from Fcntl
+  my $io = io_open('r', $filename);
 
-Open file and make it non blocking
+Open file and make it non blocking using C<sysopen>, you can use shortcuts C<"r", "rw", "w">
 
 =head2 io_open_anon
 
+Open temp file, make it non_blocking, using C<open $fh, $extr, undef>
+
 =head2 io_socket
 
 Create a socket. Make it v6only for IPv6 and nodelay for TCP. By default AF_INET6
