@@ -12,9 +12,6 @@ use Carp 'croak';
 sub net_gen_saddr_family($ip, $port) : Export {
   $port ||= 0;
 
-  # wildcard => V6
-  return (pack_sockaddr_in6($port, IN6ADDR_ANY), AF_INET6) if $ip eq '*';
-
   my ($naddr, $family) = net_parse($ip);
   croak "bad ip $ip" unless $naddr;
   my $saddr
@@ -64,7 +61,7 @@ Evo::Lib::Net
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head2 net_gen_saddr_family
 
